#!/usr/bin/env python
# -*- coding: utf-8 -*-

# 说明：
#    维护后台相关
# History:
# Date          Author    Version       Modification
# --------------------------------------------------------------------------------------------------
# 2026/2/1    xiatn     V00.01.000    新建
# --------------------------------------------------------------------------------------------------
import json
import time

import requests
from xtn_tools_pro.utils.time_utils import get_time_timestamp_to_datestr


class A818:
    def __init__(self, x_api_key, host):
        self.__x_api_key = x_api_key
        self.__host = host
        self.__headers = {
            "accept": "application/json, text/plain, */*",
            "accept-language": "zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7",
            "content-type": "application/json",
            "priority": "u=1, i",
            "sec-ch-ua": "\"Chromium\";v=\"142\", \"Google Chrome\";v=\"142\", \"Not_A Brand\";v=\"99\"",
            "sec-ch-ua-mobile": "?0",
            "sec-ch-ua-platform": "\"Windows\"",
            "sec-fetch-dest": "empty",
            "sec-fetch-mode": "cors",
            "sec-fetch-site": "same-site",
            "x-api-key": x_api_key
        }

    def get_task_list(self, taskType=None, taskStatus=None, countryCode=None, priority=None):
        """
            获取任务列表
        :param taskType:任务类型[单选],不指定获取全部
        :param taskStatus: 任务状态[多选],不指定获取全部,-1失败;0排队;1已完成;2进行中;3关闭 列表类型
        :param countryCode: 国家[单选],不指定获取全部
        :param priority: 任务权重[单选],0插队;1加急;2平台;3一般
        :return: 
        """
        data = {
            "pageNo": 1,
            "pageSize": 500,
        }
        if taskType:
            data["taskType"] = taskType
        if isinstance(taskStatus, list):
            data["taskStatus"] = taskStatus
        if countryCode:
            # 国家 自动转大写
            data["countryCode"] = str(countryCode).upper()
        if priority:
            data["priority"] = str(priority)

        url = f"{self.__host}/filter/task/list"
        data = json.dumps(data, separators=(',', ':'))
        for _ in range(3):
            try:
                response = requests.post(url, headers=self.__headers, data=data)
                return response.json()
            except Exception as e:
                print("f[get_task_list]报错:{e}")

    def to_ji_su_du(self, total_time=60, taskType=None, taskStatus=None, countryCode=None, priority=None):
        """
            统计速度
        :param total_time:下次统计时间
        :param taskType:任务类型[单选],不指定获取全部
        :param taskStatus: 任务状态[多选],不指定获取全部,-1失败;0排队;1已完成;2进行中;3关闭 列表类型
        :param countryCode: 国家[单选],不指定获取全部
        :param priority: 任务权重[单选],0插队;1加急;2平台;3一般
        :return:
        """
        index = 0
        total_cnt_history = 0
        while True:
            json_data = self.get_task_list(taskType=taskType, taskStatus=taskStatus,
                                           countryCode=countryCode, priority=priority)
            try:
                total_cnt = 0
                for item in json_data["result"]["records"]:
                    taskProgress = item["taskProgress"]
                    total_cnt += taskProgress
                index += 1
                print(f"第{index}次", get_time_timestamp_to_datestr(), total_cnt - total_cnt_history)
                total_cnt_history = total_cnt
                time.sleep(total_time)
            except Exception as e:
                print(f"[to_ji_su_du]报错:{e}")


if __name__ == '__main__':
    pass



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# 说明：
#    装对Phone文件做去重
# History:
# Date          Author    Version       Modification
# --------------------------------------------------------------------------------------------------
# 2026/2/2    xiatn     V00.01.000    新建
# --------------------------------------------------------------------------------------------------
import os
import fnmatch
import hashlib
from tqdm import tqdm
from xtn_tools_pro.utils.log import Log
from xtn_tools_pro.utils.helpers import get_orderId_random
from xtn_tools_pro.utils.file_utils import get_file_line_cnt, get_filename, mkdirs_dir, get_file_extension, is_dir, \
    get_listdir


class FileDeduper:
    def __init__(self):
        self.__logger = Log('set_data', './xxx.log', log_level='DEBUG', is_write_to_console=True,
                            is_write_to_file=False,
                            color=True, mode='a', save_time_log_path='./logs')

    def dedup_file(self, inp_file, out_dir, out_file_name=None):
        """
            对单文件去重
        :param inp_file: 需要去重的文件
        :param out_dir:去重后文件保存在哪个目录下,如果目录不存在则会自动创建
        :param out_file_name:去重后文件名称,如果不传 默认使用的是 <inp_file> 的文件名
        :return:
        """
        if get_file_extension(inp_file) != ".txt":
            self.__logger.critical("文件不合法,只接受.txt文件")
            return

        # 根据文件路径 获取文件名
        inp_file_name = get_filename(inp_file, suffix=True)

        self.__logger.info(f"正在读取,需要去重的文件总行数...{inp_file_name}")
        line_count, duration_time = get_file_line_cnt(inp_file, duration=True)
        self.__logger.info(f"读取完成,总行数为:{line_count};耗时:{duration_time}秒...{inp_file_name}")

        # 创建输出目录
        order_id = get_orderId_random()
        out_dir = os.path.join(out_dir, order_id)
        num_shards = line_count // 10000
        num_shards = 1 if num_shards <= 0 else num_shards
        num_shards = 3000 if num_shards >= 3000 else num_shards
        self.__logger.info(f"临时文件切片为:{num_shards}")

        shard_path_list = []  # 存储切片路径
        shard_file_obj_list = []  # 存储切片文件对象
        for _ in range(num_shards):
            shard_path = f"{os.path.join(out_dir, f'{_}.tmp')}"
            mkdirs_dir(shard_path)
            shard_path_list.append(shard_path)
            shard_file_obj_list.append(open(shard_path, "w", encoding="utf-8"))

        # 写入数据
        with open(inp_file, "r", encoding="utf-8") as f_r:
            tqdm_f = tqdm(f_r, total=line_count, desc="正在去重-写入切片-步骤(1/2)",
                          bar_format="{l_bar}{bar}|{n}/{total} [预计完成时间:{remaining}]")
            for line_i in tqdm_f:
                line = line_i.strip().encode()
                line_hash = hashlib.md5(line).hexdigest()
                shard_id = int(line_hash, 16) % num_shards
                shard_file_obj_list[shard_id].write(line_i)

        # 关闭切片文件对象
        for shard_file_obj in shard_file_obj_list:
            shard_file_obj.close()

        # 根据每个切片去去重
        out_file_name = inp_file_name if not out_file_name else out_file_name
        result_w_path = os.path.join(out_dir, out_file_name)
        tqdm_f = tqdm(shard_path_list, total=len(shard_path_list), desc="正在去重-去重切片-步骤(2/2)",
                      bar_format="{l_bar}{bar}|{n}/{total} [预计完成时间:{remaining}]")
        with open(result_w_path, "w", encoding="utf-8") as f_w:
            for shard_path in tqdm_f:
                with open(shard_path, "r", encoding="utf-8") as f_r:
                    seen_list = []
                    for line_i in f_r.readlines():
                        line = line_i.strip()
                        seen_list.append(line)
                    seen_list = list(set(seen_list))
                    if seen_list:
                        w_txt = "\n".join(seen_list)
                        f_w.write(w_txt + "\n")
                os.remove(shard_path)  # 删除临时文件

        # 读取结果文件 获取去重后的数据
        with open(result_w_path, "r", encoding="utf-8") as fp_r:
            line_count = sum(1 for _ in fp_r)
        self.__logger.info(f"文件处理完毕,去重后总行数为:{line_count},结果路径:{result_w_path}")


if __name__ == '__main__':
    FileDeduper().dedup_file(inp_file=r"D:\000\xtnkk-tools\demos\113.txt",
                             out_dir=r"D:\000\xtnkk-tools\demos\data")
